# -*- coding: utf-8 -*-
from django.conf import settings
from django.utils.translation import ugettext as _
from django.contrib import admin

from jmb.core.admin.options import ExtendibleModelAdmin

from publieditor.universe import models


default_list_display = ('id', 'get_edit_icon',)
default_fieldsets = (
    _('logs admin'), {
        'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        'classes': ('collapse',)
    },
)


class UniverseAdmin(ExtendibleModelAdmin):
    list_display = default_list_display + ('status', 'title', 'name', 'img_format', 'output', 'get_url', 'path', 'get_path')
    list_editable = ('img_format',)
    fieldsets = (
        default_fieldsets,
        (_('general information'), {
            'fields': ('name', 'title', 'status', 'language',)
        },),
        (_('output'), {
            'fields': ('output', 'doc_type', 'mime_type', 'img_format')
        },),
        (_('domain'), {
            'fields': ('domain', 'path', 'username', 'password', 'secret_phrase',)
        },),
        (_('file'), {
            'fields': ('folder_name', 'file_name', 'template_name',)
        },),
        (_('filters'), {
            'fields': (
                'rich_text',
                'max_num', 'content_ordering',
                'streams', 'exclude_streams',
                'layouts', 'exclude_layouts',
                'kinds', 'exclude_kinds',
                'brands',
                'constrain', 'features'
            )
        },),
        (_('note'), {
            'fields': ('note',)
        },),
    )
    filter_horizontal = ('streams', 'layouts', 'kinds', 'brands')
    advanced_search_fields = (
        ('id', 'status', 'name__icontains'),
        ('username', 'domain', 'path'),
        ('output',),
    )

    def get_path(self, obj):
        return "<a href='/feed/%s' target='_blank'>x</a>" % obj.get_path()
    get_path.allow_tags = True
    get_path.short_description = _('link')

admin.site.register(models.Universe, UniverseAdmin)
