# -*- coding: utf-8 -*-
from __future__ import absolute_import

from django.conf import settings
if settings.CMS_ENABLED:
    from cms import views

from django.http import HttpResponse
from django.http import Http404
from django.shortcuts import get_object_or_404
from django.views.generic import DetailView
from django.views.generic.base import View

from publieditor.universe.models import Universe
from . import feeder
from .httpbasic_auth import auth_basic
from jmb.core.views.odt import PdfTemplateView


class PlistFeed(feeder.PListResponseMixin, feeder.GenericFeederView, feeder.NewsContainer):
    pass


class IosWebFeed(feeder.GenericHtmlMixin, feeder.GenericFeederView, feeder.NewsContainer):
    pass


class StreamFeed(feeder.StreamResponseMixin, feeder.GenericFeederView, feeder.NewsContainer):
    pass


class RssFlipboardFeed(feeder.RssFlipboardResponseMixin, feeder.GenericFeederView, feeder.NewsContainer):
    pass


class RssProFeed(feeder.RssProResponseMixin, feeder.GenericFeederView, feeder.NewsContainer):
    pass


class UniverseDetailView(DetailView, feeder.NewsContainer):
    model = Universe

    def dispatch(self, request, *args, **kwargs):
        universe = self.get_object()

        if not universe and settings.CMS_ENABLED:
            slug = kwargs.get('path', None)
            return views.details(request, slug=slug)

        auth_response = auth_basic(request, universe)
        if auth_response:
            return auth_response

        hash_secret = kwargs.get('secret', None)
        universe_secret = universe.get_secret()
        if hash_secret and universe_secret and hash_secret != universe_secret:
            response = HttpResponse('Authorization Required')
            # response.status_code = 401
            # response['WWW-Authenticate'] = 'Basic realm="JMB"'
            return response

        if universe.output == 'pdf':
            return feeder.GenericPDFFeed.as_view()(request, *args, universe=universe, **kwargs)

        elif universe.output == 'ios-plist':
            return PlistFeed.as_view()(request, *args, universe=universe, **kwargs)

        elif universe.output == 'ios-web':
            return IosWebFeed.as_view()(request, *args, universe=universe, **kwargs)

        elif universe.output == 'stream':
            return StreamFeed.as_view()(request, *args, universe=universe, **kwargs)

        elif universe.output == 'rss':
            return feeder.GenericRSSFeed()(request, *args, universe=universe, **kwargs)

        elif universe.output == 'rss-flipboard':
            return RssFlipboardFeed.as_view()(request, *args, universe=universe, **kwargs)

        elif universe.output == 'rss-pro':
            return RssProFeed.as_view()(request, *args, universe=universe, **kwargs)

        else:
            return super(UniverseDetailView, self).dispatch(request, *args, **kwargs)

    def get_object(self):
        self.path = self.kwargs['path']
        try:
            uni_obj = Universe.objects.get(path=self.path, status="on")
        except Universe.DoesNotExist:
            uni_obj = None
        return uni_obj
        # return get_object_or_404(Universe, path=self.path)